%define apuver 1

Name: apr-util
Version: 1.6.1
Release: 14
Summary: apr-util provides a number of helpful abstractions on top of APR.
License: ASL 2.0
URL: http://apr.apache.org
Source0: http://www.apache.org/dist/apr/%{name}-%{version}.tar.bz2

Patch6000: Updated-patch-to-compile-apr-util-against-mariadb-10.patch
Patch6001: Merge-r1822315-from-trunk.patch
Patch6002: Fix-error-handling-in-gdbm.patch
Patch6003: Merge-r1834022-r1834023-r1834024-from-trunk.patch
Patch6004: Remove-dereference-of-null-pointer.patch
Patch6005: apr-util-Add-sw64-architecture.patch
Patch6006: backport-CVE-2022-25147-apr_base64-Make-sure-encoding-decoding-lengths-fit-i.patch

BuildRequires: gcc autoconf apr-devel >= 1.6.0 gdbm-devel expat-devel libuuid-devel
BuildRequires: mariadb-connector-c-devel sqlite-devel >= 3.1.0 openldap-devel openssl-devel

Requires: apr-util%{?_isa} = %{version}-%{release}

Recommends: apr-util-openssl%{_isa} = %{version}-%{release}
Recommends: apr-util-bdb%{_isa} = %{version}-%{release}

Obsoletes: apr-util-bdb < %{version}-%{release} apr-util-mysql < %{version}-%{release}
Obsoletes: apr-util-sqlite < %{version}-%{release} apr-util-ldap < %{version}-%{release}
Obsoletes: apr-util-openssl < %{version}-%{release}
Provides: apr-util-bdb = %{version}-%{release} apr-util-mysql = %{version}-%{release}
Provides: apr-util-sqlite = %{version}-%{release} apr-util-ldap = %{version}-%{release}
Provides: apr-util-openssl = %{version}-%{release}

%description
The mission of the Apache Portable Runtime (APR) project is to create and maintain software
libraries that provide a predictable and consistent interface to underlying platform-specific
implementations. The primary goal is to provide an API to which software developers may
code and be assured of predictable if not identical behaviour regardless of the platform on
which their software is built, relieving them of the need to code special-case conditions to
work around or take advantage of platform-specific deficiencies or features.

%package devel
Summary: The development kit of apr-util.
Requires: expat-devel%{?_isa} apr-util%{?_isa} = %{version}-%{release}
Requires: gdbm-devel%{?_isa} openldap-devel%{?_isa} apr-devel%{?_isa} pkgconfig

%description devel
The development kit of apr-util.

%package pgsql
Summary: The PostgreSQL DBD driver of apr-util.
BuildRequires: libpq-devel
Requires: apr-util%{?_isa} = %{version}-%{release}

%description pgsql
The PostgreSQL DBD driver of apr-util.

%package odbc
Summary: The ODBC DBD driver of apr-util.
BuildRequires: unixODBC-devel
Requires: apr-util%{?_isa} = %{version}-%{release}

%description odbc
The ODBC DBD driver of apr-util.

%prep
%autosetup -n %{name}-%{version} -p1

%build
autoheader && autoconf
export ac_cv_ldap_set_rebind_proc_style=three
%configure --with-apr=%{_prefix} --includedir=%{_includedir}/apr-%{apuver} \
        --with-ldap=ldap_r --with-gdbm --with-sqlite3 --with-pgsql --with-mysql --with-odbc \
        --with-dbm=gdbm --without-berkeley-db --without-sqlite2 --with-crypto --with-openssl
%make_build

%install
rm -rf %{buildroot}
%make_install
install -D -m 0644 build/find_apu.m4 %{buildroot}/%{_datadir}/aclocal/find_apu.m4
rm -f %{buildroot}%{_libdir}/aprutil.exp
rm -f %{buildroot}%{_libdir}/libapr*.a
sed -i '/^old_library/s,libapr.*\.a,,' %{buildroot}%{_libdir}/libapr*.la
sed -ri '/^dependency_libs/{s,-l(pq|sqlite[0-9]|rt|dl|uuid) ,,g}' \
      %{buildroot}%{_libdir}/libapr*.la
rm -f %{buildroot}%{_libdir}/%{name}-%{apuver}/*.*a

%check
export MALLOC_CHECK_=2 MALLOC_PERTURB_=$(($RANDOM % 255 + 1))
export LD_LIBRARY_PATH=%{buildroot}/%{_libdir}/%{name}-%{apuver}
make test
%ldconfig_scriptlets

%pre

%preun

%post

%postun

%files
%doc CHANGES NOTICE
%license LICENSE
%{_libdir}/libaprutil-%{apuver}.so.*
%dir %{_libdir}/%{name}-%{apuver}
%{_libdir}/%{name}-%{apuver}/apr_dbm_gdbm*
%{_libdir}/%{name}-%{apuver}/apr_dbd_mysql*
%{_libdir}/%{name}-%{apuver}/apr_dbd_sqlite*
%{_libdir}/%{name}-%{apuver}/apr_ldap*
%{_libdir}/%{name}-%{apuver}/apr_crypto_openssl*

%files devel
%{_bindir}/apu-%{apuver}-config
%{_libdir}/libaprutil-%{apuver}.*a
%{_libdir}/libaprutil-%{apuver}.so
%{_includedir}/apr-%{apuver}/*.h
%{_libdir}/pkgconfig/*.pc
%{_datadir}/aclocal/*.m4

%files pgsql
%{_libdir}/%{name}-%{apuver}/apr_dbd_pgsql*

%files odbc
%{_libdir}/%{name}-%{apuver}/apr_dbd_odbc*

%changelog
* Tue Feb 14 2023 fuanan <fuanan3@h-partners.com> - 1.6.1-14
- Fix CVE-2022-25147

* Thu Jul 28 2022 wuzx<wuzx1226@qq.com> - 1.6.1-13
- add sw64 patch

* Sat Jun 19 2021 panxiaohe <panxiaohe@huawei.com> - 1.6.1-12
- BuildRequires: replace libdb with gdbm
- Add requires gdbm-devel

* Mon Jan 13 2020 openEuler Buildteam <buildteam@openeuler.org> - 1.6.1-11
- Delete useless files.

* Tue Oct 22 2019 openEuler Buildteam <buildteam@openeuler.org> - 1.6.1-10
- optimize spec file.

* Sat Sep 28 2019 openEuler Buildteam <buildteam@openeuler.org> - 1.6.1-9
- Package rebuild.

* Thu Sep 05 2019 openEuler Buildteam <buildteam@openeuler.org> - 1.6.1-8
- Package init.
